@@ -21,9 +21,10 @@ class TrelloError(Exception):
 class TrelloConnection(object):
 
     def __init__(self, api_key, oauth_token):
-        self.session = requests.session(
-            headers={'Accept': 'application/json',
-                     'Content-Type': 'application/json'})
+        self.session = requests.session()
+
+        self.headers={'Accept': 'application/json',
+                'Content-Type': 'application/json'}
         self.key = api_key
         self.token = oauth_token
 
@@ -36,7 +37,7 @@ class TrelloConnection(object):
         params = params or {}
         params.update({'key': self.key, 'token': self.token})
         url += '?' + urlencode(params)
-        response = self.session.request(method, url, data=body)
+        response = self.session.request(method, url, data=body, headers=self.headers)
         if response.status_code != 200:
             # TODO: confirm that Trello never returns a 201, for example, when
             # creating a new object. If it does, then we shouldn't restrict
@@ -53,6 +54,9 @@ class TrelloConnection(object):
     def put(self, path, params=None, body=None):
         return self.request('PUT', path, params, body)
 
+    def delete(self, path, params=None, body=None):
+        return self.request('DELETE', path, params, body)
+
     def get_board(self, board_id):
         return Board(self, board_id)
 
@@ -83,7 +87,6 @@ class TrelloConnection(object):
         return Member(self, 'me')
 
 
-
 class Closable(object):
     """
     Mixin for Trello objects for which you're allowed to PUT to <id>/closed.
@@ -94,6 +97,48 @@ class Closable(object):
         result = self._conn.put(path, params=params)
 
 
+class Deletable(object):
+    """
+    Mixin for Trello objects which are allowed to be DELETEd.
+    """
+    def delete(self):
+        path = self._prefix + self._id
+        self._conn.delete(path)
+
+
+class Labeled(object):
+    """
+    Mixin for Trello objects which have labels.
+    """
+
+    # TODO: instead of set_label and get_label, just override the 'labels'
+    #  property to call set and get as appropriate.
+
+    _valid_label_colors = [
+        'green',
+        'yellow',
+        'orange',
+        'red',
+        'purple',
+        'blue',
+    ]
+
+    def set_label(self, color):
+        color = color.lower()
+        if color not in self._valid_label_colors:
+            raise ValueError("invalid color")
+        path = self._prefix + self._id + '/labels'
+        params = {'value': color}
+        self._conn.post(path, params=params)
+
+    def clear_label(self, color):
+        color = color.lower()
+        if color not in self._valid_label_colors:
+            raise ValueError("invalid color")
+        path = self._prefix + self._id + '/labels/' + color
+        self._conn.delete(path)
+
+
 class Field(object):
     """
     A simple field on a Trello object.  Maps the attribute to a key in the
@@ -251,7 +296,7 @@ class Board(LazyTrello, Closable):
     members = SubList('Member')
 
 
-class Card(LazyTrello, Closable):
+class Card(LazyTrello, Closable, Deletable, Labeled):
 
     _prefix = '/cards/'
 
@@ -269,7 +314,6 @@ class Card(LazyTrello, Closable):
     checklists = ListField('idChecklists','Checklist')
     members = ListField('idMembers', 'Member')
 
-
 class Checklist(LazyTrello):
 
     _prefix = '/checklists/'
@@ -286,7 +330,7 @@ class Checklist(LazyTrello):
     # could one checklist belong to multiple cards?
 
 class CheckItem(LazyTrello):
-    
+
     _prefix = '/checkItems/'
 
     name = Field()
